(rontolisp) docs
← (scheme base)

append

(append list ...)

Returns a list of the elements of the first lists followed by the last argument. Every argument but the last is copied; the last is shared, and may be any object, which then becomes the result's tail. (append) is ().