apply
(apply proc arg ... list)
Calls proc with the elements of list as its arguments, preceded by any args given before the list.
(apply proc arg ... list)
Calls proc with the elements of list as its arguments, preceded by any args given before the list.