(rontolisp) docs
← (scheme inexact)

atan

(atan z) (atan y x)

Returns the arctangent of z in radians or, with two arguments, the angle of the point (x, y) in (-π, π], taking the signs of both into account. (atan 0), and (atan 0 x) for a positive exact x, are the exact 0.