(rontolisp) docs
← Syntax

begin

(begin expression...)

Evaluates the expressions left to right and answers the value of the last one; (begin) answers the unspecified value. At the top level of a file or the REPL, begin splices its forms into the top level, so it may contain definitions, and the REPL echoes each of its forms separately.