(rontolisp) docs
← (scheme base)

bytevector-copy!

(bytevector-copy! to at from) (bytevector-copy! to at from start) (bytevector-copy! to at from start end)

Copies the elements of from between start (inclusive, default 0) and end (exclusive, default the end) into to, starting at index at, and returns the unspecified value. When to and from are the same bytevector and the regions overlap, the result is as if the source region were copied to a temporary first.