(rontolisp) docs
← (scheme file)

call-with-input-file

(call-with-input-file string proc)

Opens the file named string as by open-input-file, calls proc with the port, closes the port when proc returns, and returns what proc returned. If proc does not return, the port stays open.