call-with-port
(call-with-port port proc)
Calls proc with port, closes port when proc returns, and returns what proc returned (all of its values). If proc does not return, port stays open.
(call-with-port port proc)
Calls proc with port, closes port when proc returns, and returns what proc returned (all of its values). If proc does not return, port stays open.