cdr
(cdr pair)
Returns the cdr of pair: for a list, the list without its first element.
Deviation: (cdr '()) answers () instead of signalling an error, like car.
(cdr pair)
Returns the cdr of pair: for a list, the list without its first element.
Deviation: (cdr '()) answers () instead of signalling an error, like car.