ceiling
(ceiling x)
Returns the smallest integer not less than x, a flonum for a flonum argument and exact for an exact one. An infinity or a NaN gives itself.
(ceiling x)
Returns the smallest integer not less than x, a flonum for a flonum argument and exact for an exact one. An infinity or a NaN gives itself.