delete-file
(delete-file string)
Deletes the file named string. A file that does not exist, or cannot be deleted, raises an error file-error? answers #t for.
(delete-file string)
Deletes the file named string. A file that does not exist, or cannot be deleted, raises an error file-error? answers #t for.