digit-value
(digit-value char)
Returns the value of char as a decimal digit (0 to 9) if it is one in any script -- exactly when char-numeric? answers #t -- otherwise #f.
(digit-value char)
Returns the value of char as a decimal digit (0 to 9) if it is one in any script -- exactly when char-numeric? answers #t -- otherwise #f.