(rontolisp) docs
← Syntax

...

pattern ... template ...

Auxiliary syntax of syntax-rules: in a pattern it matches the subpattern before it zero or more times, in a template it repeats the subtemplate before it once per match. It means nothing on its own.