error-object?
(error-object? obj)
Answers #t when obj is an error object: what error raises, or the condition of an error a built-in procedure signals. Any other raised object answers #f.
(error-object? obj)
Answers #t when obj is an error object: what error raises, or the condition of an error a built-in procedure signals. Any other raised object answers #f.