for-each
(for-each proc list1 list2 ...)
Applies proc element-wise to the lists, from first to last, for its effect, like map without collecting results. With several lists it stops at the shortest. The value is unspecified.
11
22
(for-each proc list1 list2 ...)
Applies proc element-wise to the lists, from first to last, for its effect, like map without collecting results. With several lists it stops at the shortest. The value is unspecified.
11
22