gcd
(gcd n ...)
Returns the greatest common divisor of its arguments, always non-negative; (gcd) is 0. An inexact integer such as 2.0 is accepted and makes the result inexact; an argument that is not an integer signals an error.
(gcd n ...)
Returns the greatest common divisor of its arguments, always non-negative; (gcd) is 0. An inexact integer such as 2.0 is accepted and makes the result inexact; an argument that is not an integer signals an error.