(rontolisp) docs
← (scheme base)

get-output-bytevector

(get-output-bytevector port)

Returns a new bytevector of the bytes written so far to port, which must be a port made by open-output-bytevector.