(rontolisp) docs
← Syntax

include-ci

(include-ci "file"...)

Like include, but reads each file as if it began with #!fold-case: identifiers and character names are folded to lower case, strings are not.

; file: loud.scm
(DEFINE (SHOUT X) (STRING-APPEND X "!"))
hey!