(rontolisp) docs
← (scheme r5rs)

inexact->exact

(inexact->exact z)

The R5RS name of exact: returns the exact number equal to z, a flonum converting to the exact value of its binary representation. It belongs to (scheme r5rs) and is visible only to a file with no import.