let*
(let* ((variable init)...) body...)
Like let, but binds the variables one after another, so each init sees the variables bound before it.
(let* ((variable init)...) body...)
Like let, but binds the variables one after another, so each init sees the variables bound before it.