let*-values
(let*-values ((formals expression)...) body...)
Like let-values, but binds the formals one clause after another, so each expression sees the variables bound by the clauses before it.
(let*-values ((formals expression)...) body...)
Like let-values, but binds the formals one clause after another, so each expression sees the variables bound by the clauses before it.