(rontolisp) docs
← Syntax

let-values

(let-values ((formals expression)...) body...)

Evaluates each expression, which answers multiple values, and binds them to the matching formals, then evaluates body. formals has the shape of a lambda parameter list, so (a . rest) and a single variable collect the remaining values as a list.