(rontolisp) docs
← Syntax

letrec

(letrec ((variable init)...) body...)

Binds the variables so that every init can refer to all of them, which is how mutually recursive local procedures are written. Each init should be a lambda or otherwise not use the value of another variable of the same letrec.