(rontolisp) docs
← Syntax

letrec*

(letrec* ((variable init)...) body...)

Like letrec, but evaluates the inits left to right, so an init may use the value of a variable bound before it. Internal definitions in a body behave like letrec*.