(rontolisp) docs
← Syntax

letrec-syntax

(letrec-syntax ((keyword (syntax-rules ...))...) body...)

Like let-syntax, but the transformers see every keyword it binds, so the macros may use themselves and each other.