(scheme read)
Reading a datum from the current input port, or from the port given as the argument. The character and line readers are (scheme base)'s (input).
| Name | Example | Result |
|---|---|---|
read | (read) | (1 "two" #\3) on input (1 "two" #\3) |
Reading a datum from the current input port, or from the port given as the argument. The character and line readers are (scheme base)'s (input).
| Name | Example | Result |
|---|---|---|
read | (read) | (1 "two" #\3) on input (1 "two" #\3) |