(rontolisp) docs
← SICP Names

list-index

(list-index pred list)

Returns the zero-based position of the first element of list for which pred returns a true value, or #f when there is none. Only one list is accepted. A Structure and Interpretation of Computer Programs (SICP)/MIT name, not R7RS: no library exports it, so it is visible only to a file with no import and at the REPL.