list?
(list? obj)
Returns #t when obj is a proper list -- the empty list, or a chain of pairs ending in it -- otherwise #f, a circular list included.
(list? obj)
Returns #t when obj is a proper list -- the empty list, or a chain of pairs ending in it -- otherwise #f, a circular list included.