(rontolisp) docs
← (scheme base)

list-tail

(list-tail list k)

Returns the sublist of list obtained by omitting its first k elements. The result shares structure with list.

Deviation: a k past the end is not an error; the result is ().