(rontolisp) docs
← (scheme base)

map

(map proc list1 list2 ...)

Applies proc element-wise to the lists and returns the list of results, in order. With several lists, proc takes one argument per list and the result is as long as the shortest list.