min
(min x1 x2 ...)
Returns the smallest argument. If any argument is inexact, the result is inexact: (min 1 2.0) is 1.0. Takes at least one argument.
(min x1 x2 ...)
Returns the smallest argument. If any argument is inexact, the result is inexact: (min 1 2.0) is 1.0. Takes at least one argument.