-
(- z) (- z1 z2 ...)
With one argument, returns its negation; with more, subtracts the rest from the first, left to right. At least one argument is required.
(- z) (- z1 z2 ...)
With one argument, returns its negation; with more, subtracts the rest from the first, left to right. At least one argument is required.