newline
(newline [port])
Writes an end of line to the current output port. With port, it writes there instead; port must be an open textual output port.
one
two
(newline [port])
Writes an end of line to the current output port. With port, it writes there instead; port must be an open textual output port.
one
two