(rontolisp) docs
← (scheme file)

open-binary-input-file

(open-binary-input-file string)

Opens the file named string and returns a binary input port reading its bytes. A file that cannot be opened raises an error file-error? answers #t for.