(rontolisp) docs
← (scheme file)

open-binary-output-file

(open-binary-output-file string)

Creates the file named string, emptying it if it exists, and returns a binary output port writing its bytes. A file that cannot be created raises an error file-error? answers #t for. Close the port with close-port, as for open-output-file.