(rontolisp) docs
← (scheme base)

open-input-bytevector

(open-input-bytevector bytevector)

Returns a binary input port that reads the bytes of bytevector (a copy: changing bytevector later does not change what is read).