open-output-bytevector
(open-output-bytevector)
Returns a binary output port that accumulates the bytes written to it, for get-output-bytevector.
(open-output-bytevector)
Returns a binary output port that accumulates the bytes written to it, for get-output-bytevector.