open-output-string
(open-output-string)
Returns a textual output port that accumulates what is written to it, for get-output-string.
(open-output-string)
Returns a textual output port that accumulates what is written to it, for get-output-string.