or
(or test...)
Evaluates the tests left to right and answers the first value that is not #f, without evaluating the rest; answers #f when every test is false. (or) is #f.
(or test...)
Evaluates the tests left to right and answers the first value that is not #f, without evaluating the rest; answers #f when every test is false. (or) is #f.