raise-continuable
(raise-continuable obj)
Raises obj like raise, except that the innermost handler's value becomes the value of the raise-continuable call, and the program continues from there. Caught by a guard, it behaves as raise.
(raise-continuable obj)
Raises obj like raise, except that the innermost handler's value becomes the value of the raise-continuable call, and the program continues from there. Caught by a guard, it behaves as raise.