sin
(sin z)
Returns the sine of z, in radians. (sin 0) is the exact 0; any other argument gives a flonum, with the same digits on every backend.
(sin z)
Returns the sine of z, in radians. (sin 0) is the exact 0; any other argument gives a flonum, with the same digits on every backend.