(rontolisp) docs
← SICP Names

stream-append

(stream-append stream ...)

Returns the stream of the elements of each argument stream in turn, computed lazily. A Structure and Interpretation of Computer Programs (SICP)/MIT name, not R7RS: no library exports it, so it is visible only to a file with no import and at the REPL.