stream-car
(stream-car stream)
Returns the first element of a non-empty stream; the empty stream signals an error. A Structure and Interpretation of Computer Programs (SICP)/MIT name, not R7RS: no library exports it, so it is visible only to a file with no import and at the REPL.