stream-filter
(stream-filter pred stream)
Returns the stream of the elements of stream for which pred returns a true value, computed lazily, so it works on infinite streams. A Structure and Interpretation of Computer Programs (SICP)/MIT name, not R7RS: no library exports it, so it is visible only to a file with no import and at the REPL.