(rontolisp) docs
← SICP Names

stream-for-each

(stream-for-each proc stream)

Calls proc on each element of a finite stream in order, for its effect. Only one stream is accepted. A Structure and Interpretation of Computer Programs (SICP)/MIT name, not R7RS: no library exports it, so it is visible only to a file with no import and at the REPL.

1
2
3