(rontolisp) docs
← SICP Names

stream-tail

(stream-tail stream k)

Returns the stream left after dropping the first k elements of stream, forcing each dropped cell. A Structure and Interpretation of Computer Programs (SICP)/MIT name, not R7RS: no library exports it, so it is visible only to a file with no import and at the REPL.