string-append
(string-append string ...)
Returns a new string holding the characters of the given strings in order. With no arguments it returns the empty string.
(string-append string ...)
Returns a new string holding the characters of the given strings in order. With no arguments it returns the empty string.