string>?
(string>? string1 string2 string3 ...)
Returns #t if the strings are strictly decreasing in lexicographic order, otherwise #f. At least two arguments are required.
(string>? string1 string2 string3 ...)
Returns #t if the strings are strictly decreasing in lexicographic order, otherwise #f. At least two arguments are required.