substring
(substring string start end)
Returns a new string holding the characters of string from index start (inclusive) to end (exclusive). Both indexes are required.
(substring string start end)
Returns a new string holding the characters of string from index start (inclusive) to end (exclusive). Both indexes are required.