(rontolisp) docs
← Syntax

syntax-error

(syntax-error message argument...)

Reports message, a string, followed by the arguments as written, as an error when the file is read. Meant for a template, so that a use no other rule accepts names what is wrong with it.