_
_
Auxiliary syntax of syntax-rules: in a pattern it matches anything and binds nothing, so it may appear more than once. It means nothing on its own.
_
Auxiliary syntax of syntax-rules: in a pattern it matches anything and binds nothing, so it may appear more than once. It means nothing on its own.