unless
(unless test expression...)
If test is #f, evaluates the expressions and answers the last value; otherwise the value is unspecified. At least one expression is required.
(unless test expression...)
If test is #f, evaluates the expressions and answers the last value; otherwise the value is unspecified. At least one expression is required.