vector-ref
(vector-ref vector k)
Returns the element at zero-based index k of vector. An index out of range ends the program with an error.
(vector-ref vector k)
Returns the element at zero-based index k of vector. An index out of range ends the program with an error.