vector->list
(vector->list vector) (vector->list vector start) (vector->list vector start end)
Returns a list of the elements of vector, or of the part from start (inclusive) to end (exclusive, default the end of the vector).
(vector->list vector) (vector->list vector start) (vector->list vector start end)
Returns a list of the elements of vector, or of the part from start (inclusive) to end (exclusive, default the end of the vector).