when
(when test expression...)
If test is true, evaluates the expressions and answers the last value; otherwise the value is unspecified. At least one expression is required.
(when test expression...)
If test is true, evaluates the expressions and answers the last value; otherwise the value is unspecified. At least one expression is required.