call-with-values
(call-with-values producer consumer)
Calls producer with no arguments and passes the values it returns as the arguments of consumer, returning what consumer returns.
(call-with-values producer consumer)
Calls producer with no arguments and passes the values it returns as the arguments of consumer, returning what consumer returns.