delay-force
(delay-force expression)
Answers a promise that, when forced, evaluates expression (which should answer a promise) and forces that promise in turn. A chain of delay-forces is forced iteratively, so a lazy loop of 100,000 steps runs in constant stack. If expression answers something other than a promise, forcing answers that value.