file-error?
(file-error? obj)
Answers #t when obj is the error of a failed file operation: a file the (scheme file) procedures cannot open, create or delete, or a file-error signaled by Common Lisp code the program calls.
(file-error? obj)
Answers #t when obj is the error of a failed file operation: a file the (scheme file) procedures cannot open, create or delete, or a file-error signaled by Common Lisp code the program calls.