force
(force promise)
Answers the value of promise, evaluating its expression the first time and remembering the value. force of an object that is not a promise answers the object itself.
(force promise)
Answers the value of promise, evaluating its expression the first time and remembering the value. force of an object that is not a promise answers the object itself.