open-input-file
(open-input-file string)
Opens the file named string and returns a textual input port reading it. A file that cannot be opened raises an error file-error? answers #t for. Close the port with close-port when done.
(open-input-file string)
Opens the file named string and returns a textual input port reading it. A file that cannot be opened raises an error file-error? answers #t for. Close the port with close-port when done.