round
(round x)
Returns the integer closest to x; a value exactly halfway rounds to the even integer. A flonum argument gives a flonum, an exact one an exact integer. An infinity or a NaN gives itself.
(round x)
Returns the integer closest to x; a value exactly halfway rounds to the even integer. A flonum argument gives a flonum, an exact one an exact integer. An infinity or a NaN gives itself.