the-empty-stream
the-empty-stream
A variable holding the empty stream, which is the empty list '(). A Structure and Interpretation of Computer Programs (SICP)/MIT name, not R7RS: no library exports it, so it is visible only to a file with no import and at the REPL.