write-bytevector
(write-bytevector bytevector [port [start [end]]])
Writes the bytes of bytevector from index start up to, not including, end to the binary output port port. Without port it is an error, as for write-u8.
(write-bytevector bytevector [port [start [end]]])
Writes the bytes of bytevector from index start up to, not including, end to the binary output port port. Without port it is an error, as for write-u8.