write-shared
(write-shared obj [port])
Like write, but every pair or vector that occurs more than once in obj is written with a datum label, not only those on a cycle. With port, it writes there instead; port must be an open textual output port.
(#0=(1 2) #0#)