write-simple
(write-simple obj [port])
Like write, but writes shared structure out each time it occurs. It is the same as write on data without cycles; it does not detect cycles. With port, it writes there instead; port must be an open textual output port.
((1 2) (1 2))